/////////////////////////////////////////////////////////////
//                                                         //
//    "The twelve colonies of Kobol" planetary system      //
//                for SpaceEngine v0.96                    //
//                                                         //
//                     Version 1.1                         //
//                                                         //
// Data are taken from "The twelve colonies of Kobol" map. //
// Semimajor axis of binary systems are corrected using    //
// actual mass ratio data. For missing data (Luminosity,   //
// MeanAnomaly etc) used some typical values. Radii of     //
// most planets are measured on the bottom-right chart,    //
// assumed Caprica radius of 6370 km. Surface colors of    //
// planets are picked from the map.                        //
//                                                         //
/////////////////////////////////////////////////////////////

Barycenter	"Cyrannus A"
{
	ParentBody     "Cyrannus"
	Orbit
	{
		// Barycenter summary mass: 1.79
		// SemiMajorAxis = 10091/2 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 10091/2 * 2 * 1.63/(1.79+1.63)
		SemiMajorAxis   4809.45
		Period          54689
		Eccentricity    0.33	// use typical value
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 98.2	// no data
		MeanAnomaly		48.5	// no data
	}
}

Barycenter	"Cyrannus B"
{
	ParentBody  "Cyrannus"
	Orbit
	{
		// Barycenter summary mass: 1.63
		// SemiMajorAxis = 10091/2 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 10091/2 * 2 * 1.79/(1.79+1.63)
		SemiMajorAxis   5281.55
		Period          54689
		Eccentricity    0.33	// use typical value
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 278.2	// no data
		MeanAnomaly		48.5	// no data
	}
}

Star	"Helios ALF"
{
	ParentBody  "Cyrannus A"
	Class       "G2V"
	Mass        1.0
	Luminosity  1.0	// no data, use typical value of K1V star
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 2 * 63 * 0.79/(1.0+0.79)
		SemiMajorAxis   55.6089
		Period          333
		Eccentricity    0.0		// no data
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 158.2	// no data
		MeanAnomaly		228.5	// no data
	}
}

Star	"Helios BET"
{
	ParentBody  "Cyrannus A"
	Class       "K1V"
	Mass        0.79
	Luminosity  0.34	// no data, use typical value of K1V star
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 63 * 2 * 1.0/(1.0+0.79)
		SemiMajorAxis   70.3911
		Period          333
		Eccentricity    0.0		// no data
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 338.2	// no data
		MeanAnomaly		228.5	// no data
	}
}

Star	"Helios GAM"
{
	ParentBody  "Cyrannus B"
	Class       "G9V"
	Mass        0.89
	Luminosity  0.43	// no data, use typical value of K1V star
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 70 * 2 * 0.74/(0.89+0.74)
		SemiMajorAxis   63.5583
		Period          434
		Eccentricity    0.0		// no data
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 86.3	// no data
		MeanAnomaly		228.5	// no data
	}
}

Star	"Helios DEL"
{
	ParentBody  "Cyrannus B"
	Class       "K2V"
	Mass        0.74
	Luminosity  0.26	// no data, use typical value of K1V star
	Orbit
	{
		// SemiMajorAxis = 63 from map data
		// Use correct value from actual mass ratio:
		// SemiMajorAxis = 70 * 2 * 0.89/(0.89+0.74)
		SemiMajorAxis   76.4417
		Period          434
		Eccentricity    0.0		// no data
		Inclination		0.0		// no data
		AscendingNode	0.0		// no data
		ArgOfPericenter 266.3	// no data
		MeanAnomaly		228.5	// no data
	}
}

Planet	"Ragnar"
{
	ParentBody     "Cyrannus B"
	Class	       "GasGiant"

	Radius          69222

	RotationPeriod  10.27	// no data
	Obliquity       8.5		// no data
	EqAscendNode    3.2		// no data

	Albedo          0.66	// no data
	Color         ( 0.75 0.75 1.0 )

	Surface
	{
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      4
		twistMagn       0.3
	}
	
	Clouds
	{
		Coverage  0.12
	}

	Atmosphere
	{
		Height   1000.0
		Model   "Earth"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		// IRL orbit with SMA 110 a.u. must be unstable
		SemiMajorAxis   580		// 110
		Period          889.75
		Eccentricity    0.0		// no data
		Inclination		0		// no data
		AscendingNode	0		// no data
		ArgOfPericenter 168.5	// no data
		MeanAnomaly		229.3	// no data
	}
}

Moon	"Sigard"
{
	ParentBody     "Ragnar"
	Class	       "Selena"

	Radius          2011	// no data

	Albedo          0.3
	Color         ( 0.850 0.850 1.000 )

	Orbit
	{
		SemiMajorAxis  0.00233	// no data
		Eccentricity   0.0		// no data
		Inclination    0.04		// no data
		AscendingNode  0		// no data
		ArgOfPericen   293.0	// no data
		MeanAnomaly    315.7	// no data
	}
}

Planet	"Icarus"
{
	ParentBody     "Helios ALF"
	Class	       "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          3098	// no data

	Albedo          0.32	// no data

	Atmosphere
	{
		Height      130
		Pressure    3.6
		Density	    5.8
		Model      "Venus"
		Bright      5.0
		Opacity     0.5
	}

	Clouds
	{
		Coverage    0.06
		mainFreq    1.0
		twistMagn   3.8
		Velocity    220
		Height      16
		BumpHeight  0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.12		// no data
		Eccentricity   0.0		// no data
		Inclination    0.13		// no data
		AscendingNode  0		// no data
		ArgOfPericen   68.3		// no data
		MeanAnomaly    76.2		// no data
	}
}

Planet	"Picon"
{
	ParentBody     "Helios ALF"
	Class	       "Terra"

	Radius          6250	// no data

	RotationPeriod  23.5	// no data
	Obliquity       8.5		// no data
	EqAscendNode    3.2		// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.50
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      6.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.25
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.10
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	NoRings  true

	Atmosphere
	{
		Height      55
		Pressure    0.76
		Density	    1.10
		Model      "Earth"
	}

	Orbit
	{
		SemiMajorAxis   0.75	// no data
		Eccentricity    0.02	// no data
		// Extreme inclination visible on the map
		Inclination     16.6	// no data
		AscendingNode   0		// no data
		ArgOfPericen    51.1	// no data
		MeanAnomaly     134.5	// no data
	}
}

Barycenter	"Caprica-Gemenon"
{
	ParentBody     "Helios ALF"
	Orbit
	{
		SemiMajorAxis   1.0		// no data
		Eccentricity    0.005	// no data
		Inclination     0.0		// no data
		AscendingNode   0		// no data
		ArgOfPericen    117.2	// no data
		MeanAnomaly     236.5	// no data
	}
}

Planet	"Caprica"
{
	ParentBody     "Caprica-Gemenon"
	Class	       "Terra"

	Radius          6370	// no data
	Mass            0.98    // no data

	RotationPeriod  28.3	// no data
	Obliquity       0.0		// no data
	EqAscendNode    28.6	// no data

	Albedo          0.3
	Color         ( 0.85 0.95 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.86, 0.33, 0.39)
		seaLevel        0.46
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.87
		BumpHeight      8.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.91
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.14
		mainFreq    1.0
		twistMagn   3.5
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      60
		Greenhouse  15
		Pressure    1.0
		Density	    1.29
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		// 493000/2 km with mass ratio 0.84:0.98
		SemiMajorAxis   0.0015206
		Period          0.0772	// 28.2 days
		Eccentricity    0.02	// no data
		Inclination     24.5	// no data
		AscendingNode   28.6	// no data
		ArgOfPericen    68.5	// no data
		MeanAnomaly     233.2	// no data
	}
}

Planet	"Gemenon"
{
	ParentBody     "Caprica-Gemenon"
	Class	       "Terra"

	Radius          6051	// no data
	Mass            0.84    // no data

	RotationPeriod  24.0	// no data
	Obliquity       0.0		// no data
	EqAscendNode    28.6	// no data

	Albedo          0.3
	Color         ( 1.00 0.95 0.70 )

	Surface
	{
		Style           0.20
		Life            true
		Randomize      (0.86, 0.33, 0.39)
		seaLevel        0.40
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.91
		colorLowPlants  (0.69, 0.58, 0.38, 0.00)
		colorUpPlants   (0.59, 0.50, 0.31, 0.00)
		BumpHeight      13.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          5.4
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.06
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      60
		Greenhouse  8
		Pressure    0.9
		Density	    1.2
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		// 493000/2 km with mass ratio 0.84:0.98
		SemiMajorAxis   0.0017745
		Period          0.0772	// 28.2 days
		Eccentricity    0.02	// no data
		Inclination     24.5	// no data
		AscendingNode   28.6	// no data
		ArgOfPericen    248.5	// no data
		MeanAnomaly     233.2	// no data
	}
}

Planet	"Tauron"
{
	ParentBody     "Helios ALF"
	Class	       "Terra"

	Radius          7962.5	// no data

	RotationPeriod  22.1	// no data
	Obliquity       18.5	// no data
	EqAscendNode    2.1		// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Surface
	{
		Style           0.75
		Life            true
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.38
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		colorLowPlants  (0.44, 0.29, 0.22, 0.00)
		colorUpPlants   (0.47, 0.32, 0.28, 0.00)
		BumpHeight      12.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          4.674
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.08
		mainFreq    1.0
		twistMagn   3.5
		Velocity    40
		Height      12
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      52
		Greenhouse  34
		Pressure    0.76
		Density	    1.10
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.42	// no data
		Eccentricity    0.003	// no data
		Inclination     0.6		// no data
		AscendingNode   0		// no data
		ArgOfPericen    26.5	// no data
		MeanAnomaly     324.1	// no data
	}
}

Moon	"Minos"
{
	ParentBody     "Tauron"
	Class	       "Desert"

	Radius          2728	// no data

	Obliquity       4.5		// no data
	EqAscendNode    18.3	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Surface
	{
		Style           0.75
		Life            false
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.1
		icecapLatitude  0.89
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		BumpHeight      22.6
	}

	Atmosphere
	{
		Height      150
		Pressure    0.2
		Density	    0.56
		Model      "Mars"
	}
	
	Rings
	{
		InnerRadius     4072
		OuterRadius     5615
		FrontBright     1.0
		BackBright      5.0
		Density         0.03
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   0.00187	// no data
		Eccentricity    0.006	// no data
		Inclination     22.6	// no data
		AscendingNode   18.2	// no data
		ArgOfPericen    126.5	// no data
		MeanAnomaly     34.7	// no data
	}
}

Planet	"Zeus"
{
	ParentBody     "Helios ALF"
	Class	       "GasGiant"

	Radius          76500

	RotationPeriod  8.75	// no data
	Obliquity       3.5		// no data
	EqAscendNode    2.3		// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.80
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.3
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   5.2		// no data
		Eccentricity    0.0		// no data
		Inclination		1.2		// no data
		AscendingNode	0		// no data
		ArgOfPericenter 254.2	// no data
		MeanAnomaly		135.9	// no data
	}
}

Moon	"Hebe"
{
	ParentBody     "Zeus"
	Class	       "Desert"

	Radius          1327	// no data

	Albedo          0.2
	Color         ( 1.00 1.00 0.75 )

	Surface
	{
		Style           0.75
		BumpHeight      32.6
	}

	Atmosphere
	{
		Height      150
		Pressure    0.06
		Density	    0.16
		Model      "Mars"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0019	// no data
		Eccentricity    0.001	// no data
		Inclination     3.5		// no data
		AscendingNode   2.3		// no data
		ArgOfPericen    126.5	// no data
		MeanAnomaly     346.2	// no data
	}
}

Moon	"Nike"
{
	ParentBody     "Zeus"
	Class	       "IceWorld"

	Radius          1622	// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Surface
	{
		Style           0.66
		BumpHeight      30.0
	}

	Atmosphere
	{
		Height      150
		Pressure    0.36
		Density	    2.65
		Model      "Titan"
	}

	Orbit
	{
		SemiMajorAxis   0.0026	// no data
		Eccentricity    0.005	// no data
		Inclination     3.5		// no data
		AscendingNode   2.2		// no data
		ArgOfPericen    62.7	// no data
		MeanAnomaly     134.7	// no data
	}
}

DwarfPlanet	"Persephone"
{
	ParentBody     "Helios ALF"
	Class	       "IceWorld"

	Radius          550

	Albedo          0.72
	Color         ( 1.00 1.00 1.00 )

	Atmosphere
	{
		Height      50
		Pressure    0.01
		Density	    0.23
		Model      "Earth"
		Bright      2.0
		Opacity     0.2
	}

	Orbit
	{
		SemiMajorAxis   6.3		// no data
		Eccentricity    0.11	// no data
		Inclination		2.2		// no data
		AscendingNode	12.3	// no data
		ArgOfPericenter 65.4	// no data
		MeanAnomaly		61.1	// no data
	}
}

Planet	"Troy"
{
	ParentBody     "Helios BET"
	Class	       "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          3822	// no data

	RotationPeriod  23.5	// no data
	Obliquity       8.5		// no data
	EqAscendNode    3.2		// no data

	Albedo          0.22	// no data
	Color          (1.00, 0.90, 0.50)

	Surface
	{
		Style           0.3
		Randomize      (0.61, 0.35, 0.88)
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		// Yellow colors picked form the map
		colorSea       (0.44, 0.32, 0.27, 0.00)
		colorShelf     (0.56, 0.42, 0.32, 0.00)
		colorBeach     (0.74, 0.57, 0.40, 0.00)
		colorDesert    (0.53, 0.46, 0.35, 0.00)
		colorLowland   (0.67, 0.64, 0.64, 0.20)
		colorUpland    (0.69, 0.61, 0.49, 0.50)
		colorRock      (0.48, 0.41, 0.33, 0.10)
		colorSnow      (0.35, 0.29, 0.22, 1.00)
		BumpHeight      8.5
	}

	Atmosphere
	{
		Height      130
		Pressure    0.6
		Density	    1.8
		Model      "Venus"
		Bright      5.0
		Opacity     0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.37		// no data
		Eccentricity   0.0		// no data
		Inclination    0.03		// no data
		AscendingNode  0		// no data
		ArgOfPericen   17.2		// no data
		MeanAnomaly    28.1		// no data
	}
}

Planet	"Leonis"
{
	ParentBody     "Helios BET"
	Class	       "Terra"

	Radius          8281	// no data

	RotationPeriod  18.9	// no data
	// Leonis have nearly zero obliquity
	Obliquity       0.1		// no data
	EqAscendNode    0.0		// no data

	Albedo          0.28
	Color         ( 0.70 0.90 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.86, 0.43, 0.75)
		seaLevel        0.32
		mareDensity     0.0
		craterDensity   0.0
		climatePole     1.0
		climateTropic   0.625	// soft climate
		climateEquator  0.625
		icecapLatitude  0.95
		BumpHeight      6.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          2.08
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.12
		mainFreq    1.0
		twistMagn   3.3
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  5
		Pressure    1.35
		Density	    1.55
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.75	// no data
		Eccentricity    0.006	// no data
		Inclination     0.6		// no data
		AscendingNode   0		// no data
		ArgOfPericen    151.8	// no data
		MeanAnomaly     215.2	// no data
	}
}

Planet	"Pallas"
{
	ParentBody     "Helios BET"
	Class	       "Desert"

	Radius          5414.5	// no data

	RotationPeriod  26.3	// no data
	Obliquity       31.5	// no data
	EqAscendNode    1.3		// no data

	Albedo          0.2
	Color         ( 1.00 0.80 0.75 )

	Surface
	{
		Style           0.75
		Life            false
		Randomize      (0.66, 0.28, 0.56)
		seaLevel        0.18
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		colorSea       (0.18, 0.24, 0.15, 0.00)
		colorShelf     (0.15, 0.17, 0.13, 0.00)
		BumpHeight      13.2
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Atmosphere
	{
		Height      70
		Pressure    0.08
		Density	    0.11
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.98	// no data
		Eccentricity    0.003	// no data
		// Extreme inclination visible on the map
		Inclination     -18.6	// no data
		AscendingNode   6.6		// no data
		ArgOfPericen    158.2	// no data
		MeanAnomaly     121.8	// no data
	}
}

Planet	"Virgon"
{
	ParentBody     "Helios BET"
	Class	       "Terra"

	Radius          7962.5	// no data

	RotationPeriod  19.6	// no data
	Obliquity       12.7	// no data
	EqAscendNode    2.4		// no data

	Albedo          0.28
	Color         ( 0.70 0.80 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.66, 0.89, 0.51)
		seaLevel        0.42
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.88
		// blue plants colors
		colorLowPlants  (0.18, 0.33, 0.39, 0.00)
		colorUpPlants   (0.15, 0.26, 0.33, 0.00)
		BumpHeight      6.5
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          2.73
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.12
		mainFreq    1.0
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  55
		Pressure    1.3
		Density	    1.5
		Model      "Neptune"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.23	// no data
		Eccentricity    0.003	// no data
		Inclination     0.9		// no data
		AscendingNode   0		// no data
		ArgOfPericen    15.2	// no data
		MeanAnomaly     312.6	// no data
	}
}

Moon	"Hibernia"
{
	ParentBody     "Virgon"
	Class	       "Desert"

	Radius          4459	// no data

	Albedo          0.15
	Color         ( 1.00 1.00 0.90 )

	Surface
	{
		Style           0.25
		Life            false
		Randomize      (0.77, 0.38, 0.12)
		seaLevel        0.1
		icecapLatitude  1.0
		mareFreq        2.5
		mareDensity     0.25
		craterFreq      50.0
		craterDensity   0.4
		craterOctaves   10
		craterMagn      0.2
		BumpHeight      16.9
	}

	Atmosphere
	{
		Height      150
		Pressure    0.02
		Density	    0.04
		Model      "Mars"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.00211	// no data
		Eccentricity    0.001	// no data
		Inclination     12.6	// no data
		AscendingNode   2.2		// no data
		ArgOfPericen    61.5	// no data
		MeanAnomaly     44.6	// no data
	}
}

Planet	"Hera"
{
	ParentBody     "Helios BET"
	Class	       "GasGiant"

	Radius          37500

	RotationPeriod  10.1	// no data
	Obliquity       5.8		// no data
	EqAscendNode    3.6		// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.66
		Randomize      (0.13, 0.0087, 0.26)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      3
		twistMagn       0.1
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   3.8		// no data
		Eccentricity    0.0		// no data
		Inclination		0.6		// no data
		AscendingNode	0		// no data
		ArgOfPericenter 51.3	// no data
		MeanAnomaly		93.9	// no data
	}
}

Moon	"Euboea"
{
	ParentBody     "Hera"
	Class	       "IceWorld"

	Radius          991	// no data

	Albedo          0.65
	Color         ( 1.00 1.00 1.00 )

	Surface
	{
		Style           0.25
		BumpHeight      32.6
	}

	Orbit
	{
		SemiMajorAxis   0.0016	// no data
		Eccentricity    0.001	// no data
		Inclination     0.03	// no data
		AscendingNode   2.3		// no data
		ArgOfPericen    26.5	// no data
		MeanAnomaly     34.5	// no data
	}
}

Moon	"Iris"
{
	ParentBody     "Hera"
	Class	       "IceWorld"

	Radius          1366	// no data

	Albedo          0.59
	Color         ( 1.00 1.00 0.95 )

	Surface
	{
		Style           0.66
		BumpHeight      30.0
	}

	Orbit
	{
		SemiMajorAxis   0.0022	// no data
		Eccentricity    0.005	// no data
		Inclination     0.05	// no data
		AscendingNode   2.2		// no data
		ArgOfPericen    162.3	// no data
		MeanAnomaly     74.5	// no data
	}
}

Planet	"Tanatos"
{
	ParentBody     "Helios GAM"
	Class	       "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          5096	// no data

	Albedo          0.16	// no data

	Atmosphere
	{
		Height      110
		Pressure    40.0
		Density	    26.3
		Model      "Venus"
		Bright      10.0
		Opacity     1.0
	}

	Clouds
	{
		Coverage    0.25
		mainFreq    1.0
		twistMagn   3.8
		Velocity    220
		Height      16
		BumpHeight  0.5
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.3		// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   37.2		// no data
		MeanAnomaly    17.8		// no data
	}
}

Planet	"Libran"
{
	ParentBody     "Helios GAM"
	Class	       "Terra"

	Radius          6051.5	// no data

	RotationPeriod  26.3	// no data
	Obliquity       31.8	// no data
	EqAscendNode    2.9		// no data

	Albedo          0.4
	Color         ( 0.70 1.00 0.86 )

	Surface
	{
		Style           0.2
		Life            true
		Randomize      (0.14, 0.18, 0.96)
		seaLevel        0.42
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      9.8
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		// Green colors visible on the map
		colorSea       (0.04, 0.20, 0.10, 1.00)
		colorShelf     (0.15, 0.46, 0.28, 1.00)
		colorBeach     (0.82, 0.72, 0.54, 0.00)
		colorDesert    (0.13, 0.17, 0.10, 0.00)
		colorLowland   (0.10, 0.16, 0.07, 0.00)
		colorUpland    (0.09, 0.11, 0.04, 0.00)
		colorRock      (0.22, 0.20, 0.20, 0.00)
		colorSnow      (1.00, 1.00, 1.00, 0.25)
		colorLowPlants (0.18, 0.24, 0.09, 0.00)
		colorUpPlants  (0.15, 0.17, 0.07, 0.00)
	}

	Ocean
	{
		Height          4.116
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.15
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Greenhouse  25
		Pressure    1.25
		Density	    1.35
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.60	// no data
		Eccentricity    0.03	// no data
		// Extreme inclination visible on the map
		Inclination     12.61	// no data
		AscendingNode   0		// no data
		ArgOfPericen    118.7	// no data
		MeanAnomaly     41.3	// no data
	}
}

Moon	"Hersa"
{
	ParentBody     "Libran"
	Class	       "Asteroid"

	Radius          14.3	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	Orbit
	{
		SemiMajorAxis  8.20e-5	// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   21.7		// no data
		MeanAnomaly    17.3		// no data
	}
}

Moon	"Pandrossas"
{
	ParentBody     "Libran"
	Class	       "Asteroid"

	Radius          18.3	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	Orbit
	{
		SemiMajorAxis  8.38e-5	// no data
		Eccentricity   0.0		// no data
		Inclination    0.0		// no data
		AscendingNode  0		// no data
		ArgOfPericen   91.2		// no data
		MeanAnomaly    65.7		// no data
	}
}

Planet	"Scorpia"
{
	ParentBody     "Helios GAM"
	Class	       "Terra"

	Radius          8281	// no data

	RotationPeriod  22.7	// no data
	Obliquity       16.1	// no data
	EqAscendNode    3.2		// no data

	Albedo          0.31
	Color         ( 0.70 0.85 1.00 )

	Surface
	{
		Style           0.5
		Life            true
		Randomize      (0.64, 0.37, 0.82)
		seaLevel        0.45
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.90
		BumpHeight      5.9
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorLowPlants (0.18, 0.24, 0.09, 0.00)
		colorUpPlants  (0.15, 0.17, 0.07, 0.00)
	}

	Ocean
	{
		Height          2.655
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.11
		mainFreq    1.0
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      50
		Greenhouse  15
		Pressure    1.40
		Density	    1.95
		Model      "Earth"
	}

	Rings
	{
		InnerRadius     16200
		OuterRadius     18800
		FrontBright     1.0
		BackBright      5.0
		Density         0.3
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   0.778	// no data
		Eccentricity    0.03	// no data
		Inclination     0.77	// no data
		AscendingNode   0		// no data
		ArgOfPericen    18.77	// no data
		MeanAnomaly     313.6	// no data
	}
}

Planet	"Sagittarion"
{
	ParentBody     "Helios GAM"
	Class	       "Terra"

	Radius          7325.5	// no data

	RotationPeriod  23.1	// no data
	Obliquity       8.3		// no data
	EqAscendNode    0.16	// no data

	Albedo          0.28
	Color         ( 0.86 0.93 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.64, 0.37, 0.82)
		seaLevel        0.39
		mareDensity     0.0
		craterDensity   0.0
		montesDensity   0.36
		icecapLatitude  0.85
		BumpHeight      7.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorSea       (0.04, 0.10, 0.20, 1.00)
		colorShelf     (0.15, 0.28, 0.43, 1.00)
		colorBeach     (0.82, 0.73, 0.57, 0.00)
		colorDesert    (0.38, 0.32, 0.22, 0.00)
		colorLowland   (0.34, 0.29, 0.18, 0.00)
		colorUpland    (0.57, 0.54, 0.42, 0.00)
		colorRock      (0.10, 0.10, 0.10, 0.00)
		colorSnow      (1.00, 1.00, 1.00, 0.50)
		colorLowPlants (0.09, 0.12, 0.05, 0.00)
		colorUpPlants  (0.08, 0.08, 0.03, 0.00)
	}

	Ocean
	{
		Height          2.847
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.16
		mainFreq    3.0
		twistMagn   3.5
		Velocity    40
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      50
		Greenhouse  40
		Pressure    1.35
		Density	    1.10
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   1.05	// no data
		Eccentricity    0.01	// no data
		Inclination     0.21	// no data
		AscendingNode   0		// no data
		ArgOfPericen    48.33	// no data
		MeanAnomaly     229.6	// no data
	}
}

Planet	"Ophion"
{
	ParentBody     "Helios GAM"
	Class	       "GasGiant"

	Radius          22500
	Mass            12.6

	RotationPeriod  17.8	// no data
	Obliquity       29.3	// no data
	EqAscendNode    0.0		// no data

	Albedo          0.66	// no data
	Color         ( 1.00 0.95 0.66 )

	Surface
	{
		Style           0.80
		Randomize      (0.81, 0.76, 0.31)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.29
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   1000.0
		Model   "Venus"
		Bright   10.0
		Opacity  1.0
	}

	Rings
	{
		InnerRadius     38500
		OuterRadius     63200
		FrontBright     1.0
		BackBright      5.0
		Density         0.03
		Exposure        2.5
	}

	Orbit
	{
		SemiMajorAxis   2.15	// no data
		Eccentricity    0.06	// no data
		// Extreme inclination visible on the map
		Inclination		-28.6	// no data
		AscendingNode	0		// no data
		ArgOfPericenter 11.3	// no data
		MeanAnomaly		38.9	// no data
	}
}

Planet	"Phoebe"
{
	ParentBody     "Helios DEL"
	Class	       "Desert"	// SpaceEngine 0.94 don't support melted planets

	Radius          4968.6	// no data

	Albedo          0.18	// no data

	Atmosphere
	{
		Height      110
		Pressure    0.09
		Density	    0.13
		Model      "Venus"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis  0.27		// no data
		Eccentricity   0.09		// no data
		Inclination    2.13		// no data
		AscendingNode  0		// no data
		ArgOfPericen   27.1		// no data
		MeanAnomaly    161.5	// no data
	}
}

Planet	"Styx"
{
	ParentBody     "Helios DEL"
	Class	       "Desert"

	Radius          6956	// no data

	RotationPeriod  26.3	// no data
	Obliquity       1.5		// no data
	EqAscendNode    1.3		// no data

	Albedo          0.21
	Color         ( 1.00 0.88 0.75 )

	Surface
	{
		Style           0.75
		Life            false
		Randomize      (0.36, 0.84, 0.66)
		seaLevel        0.36
		mareDensity     0.0
		craterDensity   0.0
		montesDensity   0.33
		BumpHeight      10.5
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    1.6
		twistMagn   1.3
		Velocity    65
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Pressure    0.12
		Density	    0.19
		Model      "Venus"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.42	// no data
		Eccentricity    0.07	// no data
		// Extreme inclination visible on the map
		Inclination     32.2	// no data
		AscendingNode   48.2	// no data
		ArgOfPericen    38.74	// no data
		MeanAnomaly     118.2	// no data
	}
}

Planet	"Aerilon"
{
	ParentBody     "Helios DEL"
	Class	       "Terra"

	Radius          7007	// no data

	RotationPeriod  23.75	// no data
	Obliquity       1.8		// no data
	EqAscendNode    2.1		// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.64, 0.77, 0.82)
		seaLevel        0.48
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.85
		BumpHeight      7.3
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
	}

	Ocean
	{
		Height          3.504
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.20
		mainFreq    2.5
		twistMagn   3.5
		Velocity    80
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  45
		Pressure    1.3
		Density	    2.1
		Model      "Earth"
	}

	NoRings  true

	Orbit
	{
		// Enter Period to equalize it with Canceron and Hestia
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8		// no data
		AscendingNode   0		// no data
		ArgOfPericen    180.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Planet	"Canceron"
{
	ParentBody     "Helios DEL"
	Class	       "Terra"

	Radius          8281	// no data

	RotationPeriod  22.12	// no data
	Obliquity       3.8		// no data
	EqAscendNode    1.2		// no data

	Albedo          0.4
	Color         ( 0.70 0.85 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.39, 0.77, 0.16)
		seaLevel        0.40
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.95
		BumpHeight      6.2
		DiffMapAlpha   "Water"
		SpecularBright  20
		SpecularPower   150
		colorSea       (0.02, 0.02, 0.04, 1.00)
		colorShelf     (0.08, 0.08, 0.12, 1.00)
		colorLowPlants (0.08, 0.10, 0.05, 0.00)
		colorUpPlants  (0.09, 0.09, 0.07, 0.00)
	}

	Ocean
	{
		Height          2.48
		SpecularBright  20
		SpecularPower   150
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    2.1
		twistMagn   3.2
		Velocity    75
		Height      5
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      55
		Greenhouse  36
		Pressure    0.81
		Density	    1.05
		Model      "Earth"
		Bright      5.0
		Opacity     0.5
	}

	NoRings  true

	Orbit
	{
		// Enter Period to equalize it with Aerilon and Hestia
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8		// no data
		AscendingNode   0		// no data
		ArgOfPericen    60.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Planet	"Hestia"
{
	ParentBody     "Helios DEL"
	Class	       "GasGiant"

	Radius          21000
	Mass            9.86

	RotationPeriod  16.8	// no data
	Obliquity       1.1		// no data
	EqAscendNode    0.7		// no data

	Albedo          0.64	// no data
	Color         ( 1.00 0.93 0.80 )

	Surface
	{
		Style           0.66
		Randomize      (0.31, 0.87, 0.62)
		colorDistFreq   7.0
		colorDistMagn   0.4
		twistZones      5
		twistMagn       0.1
	}
	
	Clouds { }
	Clouds { }
	Clouds { }

	Atmosphere
	{
		Height   800.0
		Model   "Jupiter"
		Bright   10.0
		Opacity  1.0
	}

	NoRings  true

	Orbit
	{
		// Enter Period to equalize it with Aerilon and Canceron
		Period          0.60919
		SemiMajorAxis   0.65	// no data
		Eccentricity    0.00	// no data
		Inclination     0.8		// no data
		AscendingNode   0		// no data
		ArgOfPericen    120.7	// no data
		MeanAnomaly     21.31	// no data
	}
}

Moon	"Kronos"
{
	ParentBody     "Hestia"
	Class	       "Selena"

	Radius          1223	// no data

	Albedo          0.11
	Color         ( 1.00 1.00 1.00 )

	Surface
	{
		Style           0.25
		BumpHeight      21.2
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0012	// no data
		Eccentricity    0.001	// no data
		Inclination     0.088	// no data
		AscendingNode   0.0		// no data
		ArgOfPericen    66.25	// no data
		MeanAnomaly     112.7	// no data
	}
}

Moon	"Rhea"
{
	ParentBody     "Hestia"
	Class	       "Asteroid"

	Radius          121.6	// no data

	Albedo          0.12
	Color         ( 1.000 1.000 1.000 )

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.0012	// no data
		Eccentricity    0.001	// no data
		Inclination     0.088	// no data
		AscendingNode   0.0		// no data
		ArgOfPericen    66.25	// no data
		MeanAnomaly     172.7	// no data
	}
}

Planet	"Aquaria"
{
	ParentBody     "Helios DEL"
	Class	       "Terra"

	Radius          6051.5	// no data

	RotationPeriod  25.2	// no data
	Obliquity       12.2	// no data
	EqAscendNode    2.0		// no data

	Albedo          0.28
	Color         ( 0.70 0.80 1.00 )

	Surface
	{
		Style           0.0
		Life            true
		Randomize      (0.667, 0.349, 0.571)
		seaLevel        0.55
		mareDensity     0.0
		craterDensity   0.0
		icecapLatitude  0.67
		BumpHeight      12.5
	}

	Ocean
	{
		Height          11.4125
	}

	Clouds
	{
		Coverage    0.18
		mainFreq    1.5
		twistMagn   3.5
		Velocity    80
		Height      15
		BumpHeight  0.5
	}

	Atmosphere
	{
		Height      65
		Greenhouse  8
		Pressure    0.9
		Density	    1.2
		Model      "Neptune"
	}

	NoRings  true

	Orbit
	{
		SemiMajorAxis   0.83	// no data
		Eccentricity    0.05	// no data
		// Extreme inclination visible on the map
		Inclination     -17.4	// no data
		AscendingNode   0		// no data
		ArgOfPericen    115.6	// no data
		MeanAnomaly     28.37	// no data
	}
}
